@@ -7,6 +7,7 @@ use Carp;
 use CPANPLUS::Backend;
 use CPANPLUS::Configure;
 use CPANPLUS::Error;
+use CPANPLUS::Internals::Constants;
 use POSIX qw( O_CREAT O_RDWR O_RDONLY );         # for SDBM_File
 use SDBM_File;
 use File::Fetch;
@@ -68,7 +69,12 @@ sub new {
   # Override configure settings
   $conf->set_conf( prereqs => 2 ); # force to ask callback
   $conf->set_conf( skiptest => 0 ); 
-  $conf->set_conf( no_update => 1 ); # Don't reindex during smoking
+#  unless ( ( scalar grep { -e File::Spec->catfile( $conf->get_conf('base'), $_ ) }
+#                  qw(01mailrc.txt.gz 02packages.details.txt.gz 03modlist.data.gz) ) == 3 ) {
+  $conf->set_conf( no_update => 1 )
+    if glob( catfile( 
+                    $conf->get_conf('base'), 
+                    $conf->_get_source('stored') .'*'. STORABLE_EXT, ) );
   $conf->set_conf( dist_type => 'CPANPLUS::Dist::YACSmoke' ); # this is where the magic happens.
   $conf->set_conf( cpantest => 'dont_cc' ); # Yes, we want to report test results. But not CC
   $conf->set_conf( verbose => 1 ); # set verbosity to true.
@@ -139,7 +145,7 @@ sub test {
   $self->_disconnect_db();
 
   foreach my $mod ( @mods ) {
-     eval {
+    eval {
 		CPANPLUS::Error->flush();
 		my $stat = $self->{cpanplus}->install( 
 				modules  => [ $mod ],
@@ -147,7 +153,7 @@ sub test {
 				allow_build_interactively => 0,
 				# other settings now set via set_config() method
 		);
-     };
+    };
   }
 
   $self->{cpanplus}->save_state();
